@@ -2,7 +2,7 @@
 
 ;; Author: Milan Glacier <dev@milanglacier.com>
 ;; Maintainer: Milan Glacier <dev@milanglacier.com>
-;; Version: 0.4.4
+;; Version: 0.5.1
 ;; URL: https://github.com/milanglacier/minuet-ai.el
 ;; Package-Requires: ((emacs "29") (plz "0.9") (dash "2.19.1"))
 
@@ -26,14 +26,14 @@
 ;; Floor, Boston, MA 02110-1301, USA.
 
 ;;; Commentary:
-;; AI-powered code completion with dual modes:
+;; LLM-powered code completion with dual modes:
 ;;
 ;; - Specialized prompts and various enhancements for chat-based LLMs
 ;;   on code completion tasks.
 ;; - Fill-in-the-middle (FIM) completion for compatible models
 ;;   (DeepSeek, Codestral, and some Ollama models).
 ;;
-;; Minuet supports multiple AI providers (OpenAI, Claude, Gemini,
+;; Minuet supports multiple LLM providers (OpenAI, Claude, Gemini,
 ;; Codestral, Ollama, Llama.cpp, and OpenAI-compatible providers)
 ;;
 ;; You can use it with overlay-based ghost text via
@@ -164,7 +164,7 @@ guarantee the exact number of completion items specified, as this
 parameter serves only as a prompt guideline.  The default is `3`."
   :type 'integer)
 
-(defvar minuet-default-prompt
+(defvar minuet-default-prompt-prefix-first
   "You are the backend of an AI-powered code completion engine. Your task is to
 provide code suggestions based on the user's input. The user's code will be
 enclosed in markers:
@@ -172,11 +172,15 @@ enclosed in markers:
 - `<contextAfterCursor>`: Code context after the cursor
 - `<cursorPosition>`: Current cursor location
 - `<contextBeforeCursor>`: Code context before the cursor
+"
+  "The default prefix-first style prompt for minuet completion.")
 
+(defvar minuet-default-prompt
+  (concat minuet-default-prompt-prefix-first
+          "
 Note that the user's code will be prompted in reverse order: first the code
 after the cursor, then the code before the cursor.
-"
-  "The default prompt for minuet completion.")
+") "The default prompt for minuet completion.")
 
 (defvar minuet-default-guidelines
   "Guidelines:
@@ -207,6 +211,14 @@ after the cursor, then the code before the cursor.
 {{{:context-before-cursor}}}<cursorPosition>"
   "The default template for minuet chat input.")
 
+(defvar minuet-default-chat-input-template-prefix-first
+  "{{{:language-and-tab}}}
+<contextBeforeCursor>
+{{{:context-before-cursor}}}<cursorPosition>
+<contextAfterCursor>
+{{{:context-after-cursor}}}"
+  "The default prefix-first style template for minuet chat input.")
+
 (defvar minuet-default-fewshots
   `((:role "user"
      :content "# language: python
@@ -234,6 +246,17 @@ def fibonacci(n):
 <endCompletion>
 ")))
 
+(defvar minuet-default-fewshots-prefix-first
+  `((:role "user"
+     :content "# language: python
+<contextBeforeCursor>
+def fibonacci(n):
+    <cursorPosition>
+<contextAfterCursor>
+
+fib(5)")
+    ,(cadr minuet-default-fewshots)))
+
 (defvar minuet-claude-options
   `(:model "claude-3-5-haiku-20241022"
     :max_tokens 512
@@ -279,9 +302,9 @@ def fibonacci(n):
   "Config options for Minuet Codestral provider.")
 
 (defvar minuet-openai-compatible-options
-  `(:end-point "https://api.groq.com/openai/v1/chat/completions"
-    :api-key "GROQ_API_KEY"
-    :model "llama-3.3-70b-versatile"
+  `(:end-point "https://openrouter.ai/api/v1/chat/completions"
+    :api-key "OPENROUTER_API_KEY"
+    :model "qwen/qwen2.5-32b-instruct"
     :system
     (:template minuet-default-system-template
      :prompt minuet-default-prompt
@@ -311,12 +334,12 @@ def fibonacci(n):
     :api-key "GEMINI_API_KEY"
     :system
     (:template minuet-default-system-template
-     :prompt minuet-default-prompt
+     :prompt minuet-default-prompt-prefix-first
      :guidelines minuet-default-guidelines
      :n-completions-template minuet-default-n-completion-template)
-    :fewshots minuet-default-fewshots
+    :fewshots minuet-default-fewshots-prefix-first
     :chat-input
-    (:template minuet-default-chat-input-template
+    (:template minuet-default-chat-input-template-prefix-first
      :language-and-tab minuet--default-chat-input-language-and-tab-function
      :context-before-cursor minuet--default-chat-input-before-cursor-function
      :context-after-cursor minuet--default-chat-input-after-cursor-function)
